@@ -22,7 +22,6 @@ test_that("huxreg copes with different models", {
 
 
 test_that("huxreg confidence intervals work", {
-  skip("nnet 0.7.4 has problems with tidy()")
   skip_if_not_installed("nnet")
 
   set.seed(27101975)
@@ -153,6 +152,7 @@ test_that("huxreg stars printed correctly", {
 
 test_that("huxreg works for models without tidy p values", {
   skip_if_not_installed("lme4")
+  skip_if_not_installed("broom.mixed")
 
   expect_warning(huxreg(lme4::lmer(Sepal.Width ~ Sepal.Length + (1 | Species), data = iris),
         statistics = "nobs"), "p values")
